@@ -197,6 +197,7 @@ struct terminal {
 	pid_t pid;          /* pid of the forked proccess */
 	GtkWidget *scrollbar;
 	GtkWidget *label;
+	gchar *label_text;
 };
 
 
@@ -550,15 +551,24 @@ sakura_title_changed (GtkWidget *widget, void *data)
 {
 	int page;
 	struct terminal *term;
+	const char *title;
+	gchar *window_title;
 
 	page = gtk_notebook_get_current_page(GTK_NOTEBOOK(sakura.notebook));
 	term = sakura_get_page_term(sakura, page);
-	gtk_label_set_text(GTK_LABEL(term->label),vte_terminal_get_window_title(VTE_TERMINAL(term->vte)));
+	title = vte_terminal_get_window_title(VTE_TERMINAL(term->vte));
+	window_title = g_strconcat("sakura - ", title, NULL);
+	
+	if ( (title!=NULL) && (g_strcmp0(title, "") !=0) ) {
+		gtk_label_set_text(GTK_LABEL(term->label), title);
+		gtk_window_set_title(GTK_WINDOW(sakura.main_window), window_title);
+	} else { /* Use the default values */
+		gtk_label_set_text(GTK_LABEL(term->label), term->label_text);
+		gtk_window_set_title(GTK_WINDOW(sakura.main_window), "sakura");
+	}
+
+	g_free(window_title);
 
-	gtk_notebook_set_tab_label_text(GTK_NOTEBOOK(sakura.notebook), term->hbox,
-                                    vte_terminal_get_window_title(VTE_TERMINAL(term->vte)));
-	gtk_window_set_title(GTK_WINDOW(sakura.main_window),
-                         vte_terminal_get_window_title(VTE_TERMINAL(term->vte)));
 }
 
 
@@ -1644,7 +1654,7 @@ sakura_init_popup()
 
 	item_show_first_tab=gtk_check_menu_item_new_with_label(_("Show always first tab"));
 	item_show_close_button=gtk_check_menu_item_new_with_label(_("Show tab close button"));
-	item_toggle_scrollbar=gtk_check_menu_item_new_with_label(_("Toggle scrollbar"));
+	item_toggle_scrollbar=gtk_check_menu_item_new_with_label(_("Show scrollbar"));
 	item_audible_bell=gtk_check_menu_item_new_with_label(_("Set audible bell"));
 	item_visible_bell=gtk_check_menu_item_new_with_label(_("Set visible bell"));
 	item_blinking_cursor=gtk_check_menu_item_new_with_label(_("Set blinking cursor"));
@@ -1909,7 +1919,7 @@ sakura_add_tab()
 	GtkWidget *tab_hbox;
 	GtkWidget *close_btn;
 	int index;
-	gchar *label_text;
+	//gchar *label_text;
 	gchar *cwd = NULL;
 	gint w, h;
 
@@ -1919,9 +1929,9 @@ sakura_add_tab()
 	term->vte=vte_terminal_new();
 
 	/* Create label (and optional close button) for tabs */
-	label_text=g_strdup_printf(_("Terminal %d"), sakura.label_count++);
-	term->label=gtk_label_new(label_text);
-	g_free(label_text);
+	term->label_text=g_strdup_printf(_("Terminal %d"), sakura.label_count++);
+	term->label=gtk_label_new(term->label_text);
+	//g_free(label_text);
 	tab_hbox=gtk_hbox_new(FALSE,2);
 	gtk_box_pack_start(GTK_BOX(tab_hbox), term->label, FALSE, FALSE, 0);
 	if (sakura.show_closebutton) {
